suppy.utils
===================


Bounds
-------------------------
.. autoclass:: suppy.utils.Bounds
   :members:
   :undoc-members:
   :show-inheritance:


Decorators
-----------------------------
.. autofunction:: suppy.utils.ensure_float_array


func\_wrapper
--------------------------------

.. autoclass:: suppy.utils.FuncWrapper
   :members:
   :undoc-members:
   :show-inheritance:


Linear Mapping
-------------------------
.. autoclass:: suppy.utils.LinearMapping
   :members:
   :undoc-members:
   :show-inheritance:
